==> haskell-commonmark-extensions-0.2.1.2-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 commonmark-extensions
version:              0.2.1.2
visibility:           public
id:                   commonmark-extensions-0.2.1.2-FphFi8meX6T421NCWW7jWb
key:                  commonmark-extensions-0.2.1.2-FphFi8meX6T421NCWW7jWb
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides some useful extensions to core commonmark
    syntax: smart quotes, definition lists, tables, footnotes, math,
    and more.

category:             Text
abi:                  8066cc28b1ac6e5d46b3f55dd26e7c34
exposed:              True
exposed-modules:
    Commonmark.Extensions Commonmark.Extensions.Attributes
    Commonmark.Extensions.AutoIdentifiers
    Commonmark.Extensions.Autolink Commonmark.Extensions.DefinitionList
    Commonmark.Extensions.Emoji Commonmark.Extensions.FancyList
    Commonmark.Extensions.Footnote Commonmark.Extensions.HardLineBreaks
    Commonmark.Extensions.ImplicitHeadingReferences
    Commonmark.Extensions.Math Commonmark.Extensions.PipeTable
    Commonmark.Extensions.RebaseRelativePaths
    Commonmark.Extensions.Smart Commonmark.Extensions.Strikethrough
    Commonmark.Extensions.Subscript Commonmark.Extensions.Superscript
    Commonmark.Extensions.TaskList Commonmark.Extensions.Wikilinks

import-dirs:          /usr/lib/ghc-9.0.1/site-local/commonmark-extensions-0.2.1.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/commonmark-extensions-0.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/commonmark-extensions-0.2.1.2

hs-libraries:         HScommonmark-extensions-0.2.1.2-FphFi8meX6T421NCWW7jWb
depends:
    base-4.15.0.0 commonmark-0.2.1-Ks7ZUsRwAmCES2brjPbN30
    containers-0.6.4.1 emojis-0.1-J7GYQrMPfSAExkhwN0NeBn
    filepath-1.4.2.1 network-uri-2.6.4.1-7S4IWE3bUhZ8SkxqSVXpP2
    parsec-3.1.14.0 text-1.2.4.1 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-extensions/html/commonmark-extensions.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-commonmark-extensions-0.2.1.2-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-commonmark-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 commonmark-extensions
version:              0.2.1.2
visibility:           public
id:                   commonmark-extensions-0.2.1.2-uBWJ2GEPtJ4d7iGxHiNHH
key:                  commonmark-extensions-0.2.1.2-uBWJ2GEPtJ4d7iGxHiNHH
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides some useful extensions to core commonmark
    syntax: smart quotes, definition lists, tables, footnotes, math,
    and more.

category:             Text
abi:                  570b954199e65265998b6f49ca131511
exposed:              True
exposed-modules:
    Commonmark.Extensions Commonmark.Extensions.Attributes
    Commonmark.Extensions.AutoIdentifiers
    Commonmark.Extensions.Autolink Commonmark.Extensions.DefinitionList
    Commonmark.Extensions.Emoji Commonmark.Extensions.FancyList
    Commonmark.Extensions.Footnote Commonmark.Extensions.HardLineBreaks
    Commonmark.Extensions.ImplicitHeadingReferences
    Commonmark.Extensions.Math Commonmark.Extensions.PipeTable
    Commonmark.Extensions.RebaseRelativePaths
    Commonmark.Extensions.Smart Commonmark.Extensions.Strikethrough
    Commonmark.Extensions.Subscript Commonmark.Extensions.Superscript
    Commonmark.Extensions.TaskList Commonmark.Extensions.Wikilinks

import-dirs:          /usr/lib/ghc-9.0.1/site-local/commonmark-extensions-0.2.1.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/commonmark-extensions-0.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/commonmark-extensions-0.2.1.2

hs-libraries:         HScommonmark-extensions-0.2.1.2-uBWJ2GEPtJ4d7iGxHiNHH
depends:
    base-4.15.0.0 commonmark-0.2.1-HczohdwKTDkIqPHI3btW8m
    containers-0.6.4.1 emojis-0.1-J7GYQrMPfSAExkhwN0NeBn
    filepath-1.4.2.1 network-uri-2.6.4.1-7S4IWE3bUhZ8SkxqSVXpP2
    parsec-3.1.14.0 text-1.2.4.1 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-extensions/html/commonmark-extensions.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
